%global libname libnodeupdown

%ifnarch s390 s390x
%global with_ib 1
%else
%global with_ib 0
%endif

Summary:       Node up/down detection utility
Name:          whatsup
Version:       1.12
Release:       6%{?dist}
Group:         Applications/Communications
License:       GPLv2+
URL:           https://computing.llnl.gov/linux/whatsup.html
Source0:       http://master.dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
Source1:       %{name}-hostsfile
Source2:       %{name}-pingd.service
Patch0:        %{name}-move-initscript.patch
Patch1:        %{name}-fix-initscript.patch 
Patch2:        %{name}-install-into-vendorarch.patch
BuildRequires: perl(ExtUtils::MakeMaker) expat-devel
BuildRequires: systemd-units
Requires:      %{libname} = %{version}-%{release}

%description
Whatsup is a cluster node up/down detection utility.

Whatsup can quickly calculate and output the up and down nodes of a cluster.
Whatsup allows some tools, such as Pdsh, to operate more quickly by
not operating on down nodes. Whatsup calculates the up and down nodes of a
cluster through one of several possible backend tools
and several optional cluster node databases.

%package -n    %{libname}-devel
Summary:       Development headers for %{libname}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
%description -n %{libname}-devel
development headers for %{libname}

%package -n    %{libname}
Summary:       A cluster node up/down detection library
Group:         Applications/Communications
%description -n %{libname}
A cluster node up/down detection library, with different backends

%package -n    %{libname}-backend-ganglia
Summary:       Ganglia backend for %{libname}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
BuildRequires: ganglia-devel
%description -n %{libname}-backend-ganglia
Ganglia backend module for %{libname}

%if %{with_ib}
%package -n    %{libname}-backend-openib
Summary:       Openib backend for %{libname}
Group:         Applications/Communications
BuildRequires: opensm-devel, libibcommon-devel, libibumad-devel
Requires:      %{libname} = %{version}-%{release}
%description -n %{libname}-backend-openib
openib backend module for %{libname}
%endif

%package -n    %{libname}-backend-pingd
Summary:       Pingd backend for %{libname}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
Requires:      %{name}-pingd = %{version}-%{release}
%description -n %{libname}-backend-pingd
pingd backend module for %{libname}

%package -n    %{name}-pingd
Summary:       Pingd daemon for %{name}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%description -n %{name}-pingd
pingd daemon for %{name}

%package -n    perl-%{libname}
Summary:       Perl bindings for %{libname}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
Requires:      perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
%description -n perl-%{libname}
Perl bindings for %{libname}

%package -n    %{libname}-clusterlist-hostsfile
Summary:       Hostsfile clusterlist module for %{libname}
Group:         Applications/Communications
Requires:      %{libname} = %{version}-%{release}
%description -n %{libname}-clusterlist-hostsfile
Hostsfile clusterlist module for %{libname}

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%configure --disable-static 
make %{?_smpflags}

%install
make DESTDIR=%{buildroot} install

mkdir -vp %{buildroot}%{_unitdir}
install -m 644 -p %{SOURCE2} %{buildroot}%{_unitdir}/
rm -rf %{buildroot}%{_initrddir}

# for whatsup-pingd
install -m 644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/hostsfile

mkdir -vp %{buildroot}%{perl_vendorlib}

find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -name "*.bs" -exec rm -f {} \;
find %{buildroot} -type f -name "*.la" -exec rm -f {} \;

%{_fixperms} %{buildroot}/*
touch %{buildroot}%{_sysconfdir}/hostsfile

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post -n %{name}-pingd
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun -n %{name}-pingd
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable whatsup-pingd.service > /dev/null 2>&1 || :
    /bin/systemctl stop whatsup-pingd.service > /dev/null 2>&1 || :
fi

%postun -n %{name}-pingd
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart whatsup-pingd.service >/dev/null 2>&1 || :
fi

%triggerun -n %{name}-pingd -- whatsup-pingd < 1.12-6
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply whatsup-pingd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save whatsup-pingd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del whatsup-pingd >/dev/null 2>&1 || :
/bin/systemctl try-restart whatsup-pingd.service >/dev/null 2>&1 || :

%files
%doc AUTHORS COPYING DISCLAIMER NEWS README ChangeLog
%{_bindir}/whatsdown
%{_bindir}/whatsup
%{_mandir}/man1/*

%files -n perl-%{libname}
%doc COPYING
%{_mandir}/man3/Libnodeupdown.3*
%{_mandir}/man3/Nodeupdown.3*
%{perl_vendorarch}/*
%exclude %dir %{perl_vendorarch}/auto/

%files -n %{name}-pingd
%doc COPYING
%{_unitdir}/%{name}-pingd.service
%{_sbindir}/pingd
%dir %{_libdir}/pingd
%{_libdir}/pingd/pingd_clusterlist_hostsfile.so
%config(noreplace) %{_sysconfdir}/hostsfile
%{_mandir}/man5/pingd.conf.5*
%{_mandir}/man8/pingd.8*
%{_sysconfdir}/pingd.conf

%files -n %{libname}-devel
%doc COPYING
%{_includedir}/nodeupdown.h
%dir %{_includedir}/nodeupdown
%{_includedir}/nodeupdown/*.h
%{_libdir}/libnodeupdown*.so
%{_mandir}/man3/nodeupdown*

%files -n %{libname}
%doc COPYING
%{_libdir}/libnodeupdown*.so.*
%dir %{_libdir}/nodeupdown
%{_mandir}/man3/libnodeupdown.3*
%{_mandir}/man5/nodeupdown.conf.5*
%{_sysconfdir}/nodeupdown.conf

%files -n %{libname}-backend-ganglia
%doc COPYING
%{_libdir}/nodeupdown/nodeupdown_backend_ganglia.so

%if %{with_ib}
%files -n %{libname}-backend-openib
%doc COPYING
%{_libdir}/nodeupdown/nodeupdown_backend_openib.so
%endif

%files -n %{libname}-backend-pingd
%doc COPYING
%{_libdir}/nodeupdown/nodeupdown_backend_pingd.so

%files -n %{libname}-clusterlist-hostsfile
%doc COPYING
%{_libdir}/nodeupdown/nodeupdown_clusterlist_hostsfile.so
%config(noreplace) %{_sysconfdir}/hostsfile


%changelog
* Fri Sep 23 2011 Tom Callaway <spot@fedoraproject.org> - 1.12-6
- convert to systemd

* Tue Aug 02 2011 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.12-5
- Rebuild for new opensm

* Mon Jul 25 2011 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.12-4
- Rebuild for new libopensm

* Fri Jun 17 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.12-3
- Perl mass rebuild

* Thu Mar 10 2011 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.12-2
- Install into vendorarch instead of sitearch

* Mon Mar 07 2011 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.12-1
- Upstream released new version
- Link against system-provided expat (#652981)
- Fixes FTBFS (#661001)
- Drop patch for incorrect open which was merged upstream

* Thu Sep 30 2010 Dan Horák <dan[at]danny.cz> 1.10-2
- no InfiniBand on s390(x)

* Thu Jun 24 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.10-1
- Upstream released new version

* Fri May 07 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.9-6
- Mass rebuild with perl-5.12.0

* Wed Mar 10 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.9-5
- Rebuild to pick up new opensm

* Mon Dec 21 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.9-4
- Rebuild to pick up new opensm

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.9-3
- rebuild against perl 5.10.1

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Jun 07 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.9-1
- Upstream released new version
- Add openib backend
- Move clusterlist_hostsfile to separate module.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Aug 14 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.8-1
- Upstream release new version

* Fri Apr 25 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> 1.7-1
- Initial import



